from netCDF4 import Dataset
import numpy as np
import datetime

template = 'glob_bbp_200911.nc'
datafile = '/esarchive/obs/noaa/copepod/ORCA1/copepod-2012_cmass_ORCA1_climatology_annual.nc'
outdir = '/esarchive/obs/noaa/copepod/annual_mean/zmeso-orca1/'
data = np.array(Dataset(datafile)['cmass'])

season = ['djf','mam','jja','son']

with Dataset(template) as src, Dataset(outdir + 'zmeso_2012.nc', "w") as dst:
    # copy global attributes all at once via dictionary
    dst.setncatts(src.__dict__)
    # copy dimensions
    for name, dimension in src.dimensions.items():
        dst.createDimension(
            name, (len(dimension) if not dimension.isunlimited() else None))
    # copy all file data except for the excluded
    for name, variable in src.variables.items():
        if name == 'bbp':
            x = dst.createVariable('zmeso', variable.datatype, variable.dimensions)
            dst['zmeso'][:] = data[0]/12011.
            dst['zmeso'].units = 'mol m-3'
            dst['zmeso'].standard_name = 'Total Carbon Mass'
            dst['zmeso'].long_name = 'Total Carbon Mass'
        elif name == 'time':
            x = dst.createVariable('time', variable.datatype, variable.dimensions)
            dst['time'][:] = (datetime.datetime(year=2012, month=7, day=1) - datetime.datetime(year=1970, month=1, day=01)).days
            dst['time'].units = 'days since 01/01/1970'
        else:
            x = dst.createVariable(name, variable.datatype, variable.dimensions)
            dst[name][:] = src[name][:]
            # copy variable attributes all at once via dictionary
            dst[name].setncatts(src[name].__dict__)

# for m in range(4):
#     print(m)
#     with Dataset(template) as src, Dataset(outdir + 'zmeso_2012'+ season[m] +'.nc', "w") as dst:
#         # copy global attributes all at once via dictionary
#         dst.setncatts(src.__dict__)
#         # copy dimensions
#         for name, dimension in src.dimensions.items():
#             dst.createDimension(
#                 name, (len(dimension) if not dimension.isunlimited() else None))
#         # copy all file data except for the excluded
#         for name, variable in src.variables.items():
#             if name == 'bbp':
#                 x = dst.createVariable('zmeso', variable.datatype, variable.dimensions)
#                 dst['zmeso'][:] = data[m]/12011.
#                 dst['zmeso'].units = 'mol m-3'
#                 dst['zmeso'].standard_name = 'Total Carbon Mass'
#                 dst['zmeso'].long_name = 'Total Carbon Mass'
#             elif name == 'time':
#                 x = dst.createVariable('time', variable.datatype, variable.dimensions)
#                 dst['time'][:] = (datetime.datetime(year=2012, month=3*m + 2, day=15) - datetime.datetime(year=1970, month=1, day=01)).days
#                 dst['time'].units = 'days since 01/01/1970'
#             else:
#                 x = dst.createVariable(name, variable.datatype, variable.dimensions)
#                 dst[name][:] = src[name][:]
#                 # copy variable attributes all at once via dictionary
#                 dst[name].setncatts(src[name].__dict__)