
from netCDF4 import Dataset
import numpy as np
import os
import pandas as pd
import math as m

def nearestind(lat,lon,reflat,reflon):
    nearlats=reflat[(abs(reflat-lat)<1) & (abs(reflon-lon)<1)]
    nearlons=reflon[(abs(reflat-lat)<1) & (abs(reflon-lon)<1)]
    if len(nearlons)==1:
        nearestlatind = np.where(reflat==nearlats[0])
        nearestlonind = np.where(reflon==nearlons[0])
        Jnearest = np.intersect1d(nearestlatind[0], nearestlonind[0])
        Inearest = np.intersect1d(nearestlatind[1], nearestlonind[1])
        return Jnearest[0], Inearest[0]
    elif len(nearlons)==0:
        return None, None
    else:
        dists = [m.sqrt(abs(nearlons[i]-lon)**2 + abs(nearlats[i]-lat)**2) for i in range(len(nearlons))]
        mindist = dists.index(min(dists))
        nearestlatind = np.where(reflat==nearlats[mindist])
        nearestlonind = np.where(reflon==nearlons[mindist])
        Jnearest = np.intersect1d(nearestlatind[0], nearestlonind[0])
        Inearest = np.intersect1d(nearestlatind[1], nearestlonind[1])
        return Jnearest[0], Inearest[0]

ncdffile = '/gpfs/projects/bsc32/models/nemo/v4.0/inidata/nemo/climatology/ORCA1L75/sali_ref_clim_monthly.nc'
filename =  'OPERA/copepod-2012_cmass_ORCA1_climatology_monthly.nc'

csvpath = '/esarchive/obs/noaa/copepod/original_files/copepod-2012__biomass-fields/data/'
#csvfiles = ['copepod-2012__cmass-m00-qtr.csv']
csvfiles = ['copepod-2012__cmass-m01-qtr.csv', 'copepod-2012__cmass-m02-qtr.csv', 'copepod-2012__cmass-m03-qtr.csv', 'copepod-2012__cmass-m04-qtr.csv', 'copepod-2012__cmass-m05-qtr.csv', 'copepod-2012__cmass-m06-qtr.csv', 'copepod-2012__cmass-m07-qtr.csv', 'copepod-2012__cmass-m08-qtr.csv', 'copepod-2012__cmass-m09-qtr.csv', 'copepod-2012__cmass-m10-qtr.csv', 'copepod-2012__cmass-m11-qtr.csv', 'copepod-2012__cmass-m12-qtr.csv'] ## list of csv files. can use list comprehension.
#csvfiles = ['copepod-2012__cmass-m13-qtr.csv', 'copepod-2012__cmass-m14-qtr.csv', 'copepod-2012__cmass-m15-qtr.csv', 'copepod-2012__cmass-m16-qtr.csv']

ncdfdata = Dataset(ncdffile)
netcdf_lats = np.array(ncdfdata['nav_lat'])
netcdf_lons = np.array(ncdfdata['nav_lon'])

if os.path.exists(filename):
    os.remove(filename)
out = Dataset(filename, 'w', format='NETCDF4_CLASSIC')

out.createDimension('y', np.shape(netcdf_lats)[0])
out.createDimension('x', np.shape(netcdf_lats)[1])
out.createDimension('t', len(csvfiles))

out.createVariable('nav_lat', np.float32, ('y', 'x'), fill_value=np.nan)
out['nav_lat'][:] = np.array(ncdfdata['nav_lat'])
out.createVariable('nav_lon', np.float32, ('y', 'x'), fill_value=np.nan)
out['nav_lon'][:] = np.array(ncdfdata['nav_lon'])
out.createVariable('t', np.float32, ('t'), fill_value=np.nan)
out['t'][:] = range(len(csvfiles))

cmassarr = np.empty((len(csvfiles),np.shape(netcdf_lats)[0],np.shape(netcdf_lats)[1]))
cmassarr[:] = np.nan

def change_value(i,data, arr, indlats, indlons, reflat, reflon):
    print(i, len(data))
    Jn, In, = nearestind(indlats[i], indlons[i], reflat, reflon)
    if Jn:
        arr[Jn, In] = data[i]
    return arr

for f in range(len(csvfiles)):
    csvdata=pd.read_csv(csvpath + csvfiles[f])
    cmass=np.array(csvdata['Total Carbon Mass (mg-C/m3)'])
    csvlats=np.array(csvdata['Latitude'])
    csvlons = np.array(csvdata['Longitude'])
    [change_value(i, cmass, cmassarr[f], csvlats, csvlons, netcdf_lats, netcdf_lons) for i in range(len(cmass))]

out.createVariable('cmass', np.float32, ('t','y','x'), fill_value=np.nan)
out['cmass'].setncatts({'units': u"mgC/m-3"})
print(np.shape(cmassarr))
print(np.shape(out['cmass'][:]))
out['cmass'][:] = cmassarr[:]

