from netCDF4 import Dataset
import os
import sys

def create_file_from_source(src_file, trg_file, src_var, trg_var, conv=None, unit=None):

    if not conv:
        conv=1

    src = Dataset(src_file)
    trg = Dataset(trg_file, mode='w')

    # Create the dimensions of the file
    for name, dim in src.dimensions.items():
        trg.createDimension(name, len(dim) if not dim.isunlimited() else None)

    # Copy the global attributes
    trg.setncatts({a:src.getncattr(a) for a in src.ncattrs()})

    # Create the variables in the file
    for name, var in src.variables.items():

        if name == src_var: # variable to be converted

            trg.createVariable(trg_var, var.dtype, var.dimensions)
            trg.variables[trg_var].setncatts({a: var.getncattr(a) for a in var.ncattrs()})  # attributes
            trg.variables[trg_var][:] = src.variables[name][:]*conv # values
            if unit:
                trg.variables[trg_var].units = unit

        else: # all other variables

            trg.createVariable(name, var.dtype, var.dimensions)
            trg.variables[name].setncatts({a:var.getncattr(a) for a in var.ncattrs()}) # attributes
            trg.variables[name][:] = src.variables[name][:]    # values

    # Save the file
    trg.close()

#create_file_from_source('cphyto_200909.nc', 'phycos_200909.nc', 'cphyto', 'phycos', conv=1/(12.011*1000), unit='mol m-3')

#inpath = '/esarchive/obs/esa/pp_oc-cci-v4.2/monthly/pp-orca1/'
#outpath = '/esarchive/obs/esa/pp_oc-cci-v4.2/monthly/intpp-orca1/'

inpath = sys.argv[1]
outpath = sys.argv[2]

infiles = sorted([i[-10:] for i in os.listdir(inpath)])

for f in range(len(infiles)):
    print(infiles[f][1:7])
    create_file_from_source(inpath + 'pp'+infiles[f],outpath + 'intpp'+infiles[f], 'pp', 'intpp', conv=1 / (12.011 * 86400),
                            unit='mol m-3')

