import os
import datetime
from netCDF4 import Dataset
import numpy as np
import sys

indir = '/esarchive/obs/cmems/biobgc/original_files/cmems_obs_glo_bgc3d_rep_weekly/'

files = []
for y in sorted(os.listdir(indir)):
    for f in sorted(os.listdir(indir + y)):
        files.append(y+'/'+f)

#files = files[581:]

months = sorted(list(set([f[36:42] for f in files])))
filedates = [f[36:44] for f in files]
varnames = [sys.argv[1]]
#varnames = ['chl','chl-error','bbp','bbp-error','poc','poc-error']
#varnames_und = [s.replace('-','_') for s in varnames]
varpath = '/esarchive/obs/cmems/biobgc/monthly/'


for m in months:
    filemonthweights = {}
    lenmonth = 0
    print(m)
    # identify which files contain the days of the month m and how many
    for f in files:
        d = f[36:44]
        dt = datetime.date(year=int(d[:4]),month=int(d[4:6]),day=int(d[6:]))
        wk = [dt + datetime.timedelta(days=i) for i in range(-3,4)]
        totaldays=sum(i == m for i in [str(wkd.year) + "{0:0=2d}".format(wkd.month) for wkd in wk])
        if totaldays>0:
            filemonthweights[f] = [lenmonth,lenmonth+totaldays]
            lenmonth = lenmonth + totaldays

    for v in varnames:
        old = Dataset(indir + files[0], 'r')
        new = Dataset(varpath + v + '/' + v + '_' + m + '.nc', 'w')
        print(v + '_' + m + '.nc')

        # copy global attributes all at once via dictionary
        new.setncatts(old.__dict__)
        # copy dimensions
        for name, dimension in old.dimensions.items():
            if name!='time':
                new.createDimension(
                    name, (len(dimension) if not dimension.isunlimited() else None))
        # copy all file data except for the excluded
        for name, variable in old.variables.items():
            #if name not in varnames_und + ['time']:
            if name not in ['chl','chl_error','bbp','bbp_error','poc','poc_error','time']:
                x = new.createVariable(name, variable.datatype, variable.dimensions)
                new[name][:] = old[name][:]
                # copy variable attributes all at once via dictionary
                new[name].setncatts(old[name].__dict__)

        dailyvar = np.empty((lenmonth, old.dimensions['depth'].size, old.dimensions['latitude'].size,
                           old.dimensions['longitude'].size))

        new.createVariable(v, np.float32, ('depth', 'latitude', 'longitude'), fill_value=np.nan)

        new[v].setncatts(old[v.replace('-','_')].__dict__)

        old.close()

        keys=sorted(filemonthweights.keys())

        for k in range(len(keys)):
            origfile = Dataset(indir + keys[k])
            origdata = np.array(origfile[v.replace('-','_')])[0]
            origdata[origdata==99999] = np.nan
            dailyvar[filemonthweights[keys[k]][0]:filemonthweights[keys[k]][1]] = origdata
            origfile.close()

        #print('calculating mean')
        weightedmean = np.nanmean(dailyvar,axis=0)
        #print('mean calculated')
        new[v][:] = weightedmean

        new.close()





